@@ -100,6 +100,28 @@ pub trait Font {
     /// Scaling can be done with [`as_scaled`](Self::as_scaled).
     fn line_gap_unscaled(&self) -> f32;
 
+    /// The slant angle of the font.
+    ///
+    /// Returns `0.0` if no angle or this info is not provided.
+    ///
+    /// # Example
+    /// ```
+    /// # use ab_glyph::{Font, FontRef};
+    /// # fn main() -> Result<(), ab_glyph::InvalidFont> {
+    /// let italic_font =
+    ///     FontRef::try_from_slice(include_bytes!("../../dev/fonts/OpenSans-Italic.ttf"))?;
+    /// assert_eq!(italic_font.italic_angle(), -12.0);
+    ///
+    /// let other_font = FontRef::try_from_slice(include_bytes!("../../dev/fonts/Exo2-Light.otf"))?;
+    /// assert_eq!(other_font.italic_angle(), 0.0);
+    /// # Ok(()) }
+    /// ```
+    fn italic_angle(&self) -> f32 {
+        // Note: default impl prevents this method from breaking external
+        //       Font impls written before introduction
+        0.0
+    }
+
     /// Lookup a `GlyphId` matching a given `char`.
     ///
     /// Scaling can be done with [`as_scaled`](Self::as_scaled).
@@ -182,7 +204,7 @@ pub trait Font {
         since = "0.2.22",
         note = "Deprecated in favor of `glyph_raster_image2`"
     )]
-    fn glyph_raster_image(&self, id: GlyphId, pixel_size: u16) -> Option<crate::GlyphImage> {
+    fn glyph_raster_image(&self, id: GlyphId, pixel_size: u16) -> Option<crate::GlyphImage<'_>> {
         self.glyph_raster_image2(id, pixel_size)
             .map(|i| crate::GlyphImage {
                 origin: i.origin,
@@ -199,14 +221,14 @@ pub trait Font {
     /// used to select between multiple possible images (if present); the returned image will
     /// likely not match this value, requiring you to scale it to match the target resolution.
     /// To get the largest image use `u16::MAX`.
-    fn glyph_raster_image2(&self, id: GlyphId, pixel_size: u16) -> Option<v2::GlyphImage>;
+    fn glyph_raster_image2(&self, id: GlyphId, pixel_size: u16) -> Option<v2::GlyphImage<'_>>;
 
     /// Returns raw SVG data of a range of glyphs which includes this one.
     ///
     /// Some fonts define their images as SVG rather than a raster format. SVG data here is raw and
     /// should be rendered and/or decompressed by the caller, and scaled appropriately. The SVG file
     /// might include a series of glyphs as nodes.
-    fn glyph_svg_image(&self, id: GlyphId) -> Option<GlyphSvg> {
+    fn glyph_svg_image(&self, id: GlyphId) -> Option<GlyphSvg<'_>> {
         _ = id;
         None // Avoid breaking external Font impls.
     }
@@ -321,6 +343,11 @@ impl<F: Font> Font for &F {
         (*self).line_gap_unscaled()
     }
 
+    #[inline]
+    fn italic_angle(&self) -> f32 {
+        (*self).italic_angle()
+    }
+
     #[inline]
     fn glyph_id(&self, c: char) -> GlyphId {
         (*self).glyph_id(c)
@@ -367,12 +394,12 @@ impl<F: Font> Font for &F {
     }
 
     #[inline]
-    fn glyph_raster_image2(&self, id: GlyphId, size: u16) -> Option<v2::GlyphImage> {
+    fn glyph_raster_image2(&self, id: GlyphId, size: u16) -> Option<v2::GlyphImage<'_>> {
         (*self).glyph_raster_image2(id, size)
     }
 
     #[inline]
-    fn glyph_svg_image(&self, id: GlyphId) -> Option<GlyphSvg> {
+    fn glyph_svg_image(&self, id: GlyphId) -> Option<GlyphSvg<'_>> {
         (*self).glyph_svg_image(id)
     }
 
