@@ -1,5 +1,7 @@
 use crate::{v2, Font, FontRef, FontVec, GlyphId, InvalidFont, Outline};
 use alloc::sync::Arc;
+#[cfg(not(feature = "std"))]
+use alloc::vec::Vec;
 use core::fmt;
 
 /// `Font` implementor that wraps another concrete `Font + 'static` type storing in an `Arc`.
@@ -91,6 +93,11 @@ impl Font for FontArc {
         self.0.line_gap_unscaled()
     }
 
+    #[inline]
+    fn italic_angle(&self) -> f32 {
+        self.0.italic_angle()
+    }
+
     #[inline]
     fn glyph_id(&self, c: char) -> GlyphId {
         self.0.glyph_id(c)
@@ -137,12 +144,12 @@ impl Font for FontArc {
     }
 
     #[inline]
-    fn glyph_raster_image2(&self, id: GlyphId, size: u16) -> Option<v2::GlyphImage> {
+    fn glyph_raster_image2(&self, id: GlyphId, size: u16) -> Option<v2::GlyphImage<'_>> {
         self.0.glyph_raster_image2(id, size)
     }
 
     #[inline]
-    fn glyph_svg_image(&self, id: GlyphId) -> Option<crate::GlyphSvg> {
+    fn glyph_svg_image(&self, id: GlyphId) -> Option<crate::GlyphSvg<'_>> {
         self.0.glyph_svg_image(id)
     }
 
